/* cnvsize routine: Format a printable string containing a large
   file size, giving the size in MB and bytes.
   Input is 64-bit size value (number of bytes).

   (c) Copyright 2005 by Dave Edwards.  All rights reserved.
   See the accompanying license.txt file.

   Usage:   ULONG sizehi,sizelo,opts;
            UCHAR buf[40];  <-- recommended min size
            opts=0;  <-- use opts=1 to compress out multiple blanks

            cnvsize(sizehi,sizelo,buf,sizeof(buf),opts);  <-- sets buf

   Sample output string:  "  1177375.69 MB = 1234567890123 bytes "
   This was produced by sizehi=287, sizelo=1912276171.
   Output for opts=1:  " 1177375.69 MB = 1234567890123 bytes "

   For sizehi=1, sizelo=1234567: "     4097.18 MB =    4296201863 bytes "
                             or: " 4097.18 MB = 4296201863 bytes "

   Test program:  c:\misc\testpgms\cnvsizet.c

Change Log:
09DEC2002 - Written by Dave Edwards
*/

#include <stdio.h>
#include <string.h>

typedef unsigned long int ULONG;
typedef unsigned char UCHAR;

void cnvsize(ULONG sizehi, ULONG sizelo, UCHAR buf[40], ULONG sizbuf,
             ULONG opts)
{
ULONG n1;
UCHAR tempbuf[50];
double dval1,dval2;

dval1=sizehi*4294967296.+sizelo;   /* 2**32 */
dval2=dval1/1048576.;   /* 2**20 = 1M */
if(opts==1)
    sprintf(tempbuf," %.2lf MB = %.0lf bytes ",dval2,dval1);
else
    sprintf(tempbuf," %11.2lf MB =%14.0lf bytes ",dval2,dval1);
n1=strlen(tempbuf);
if(sizbuf==0) return;
if(n1>sizbuf-1) n1=sizbuf-1;
tempbuf[n1]=0;  /* truncate if necessary */
strcpy(buf,tempbuf);
}  /* end of cnvsize */
