/* readpass.c - readpass command for Unix/Linux.

   Reads a password, without echo, and writes it to stdout.
   The input can be a password or pass phrase, containing special
   characters and perhaps leading and trailing blanks (preserved).
   The maximum password length is 200 characters.  If the input
   is longer than that, it is truncated without warning.
   The characters written to stdout are only the password itself,
   not followed by any Newline character.

   (c) Copyright 2005 by Dave Edwards.  All rights reserved.
   See the accompanying license.txt file.

   *** This program works only on a Unix or Linux system.
       Tested on:  Red Hat Linux 8.0 (gcc 3.2 C compiler)

   This program is useful in a shell script, for reading a password.
   For example:

         echo -n "Enter password: "
         mypw=`readpass`
         echo " "

   After these shell commands, the variable $mypw contains the
   entered password.  Note the backquotes around readpass, which
   tell the shell to run the readpass program and assign its
   output to the $mypw variable.

   NOTE: Some shells require records in shell scripts to have
         only LF endings, not CR LF.  If records end with CR LF,
         the shell does not complain, but acts strangely!
         Be careful if the script is edited on Windows and
         then uploaded to Linux or Unix.  The UltraEdit editor on
         Windows can convert line endings from CR LF to LF ("DOS
         to UNIX" conversion).  After conversion, FTP the file as
         a BINARY file.

   External functions called:
      rdline.c  - from c:\misc\subs\linux

   To compile:  gcc -o readpass readpass.c rdline.c

   See also:
      c:\misc\linuxprogs\md5pw_sh.bin  - shell program

Change Log:
30nov2005 - Written by Dave Edwards
*/

#include <stdio.h>

/* Prototype for called function */
int rdline(unsigned char *buf, int bufsize, int opt);

int main(void)
{
char buf[201];

rdline(buf,sizeof(buf),8);
             /* option=8: no echo, no Newline char put out */
printf("%s",buf);
return 0;
}
